Description: Bootstrap Italia
Keywords: Bootstrap Italia

SPID Quality Assessment

## SPID Quality Assessment

## Report

, Description here.

Metadata strict [SpidSpMetadataCheck]

# | Result | Name | Description
--- | --- | --- | ---
1 | success | SpidSpMetadataCheck.xsd_check : OK |
2 | success | SpidSpMetadataCheck.test_EntityDescriptor : OK |
3 | success | Only one SPSSODescriptor element must be present : OK |

Metadata extra [SpidSpMetadataCheckExtra]

# | Result | Name | Description
--- | --- | --- | ---
1 | success | The certificate #0 must not use weak signature algorithm: sha256withrsaencryption : OK |
2 | success | The key type of certificate #0 must be one of [rsaEncryption, id-ecPublicKey] - TR pag. 19 : OK |
3 | success | The key length of certificate #0 must be >= 2048. Instead it is 2048 : OK |

Authnrequest strict [SpidSpAuthnReqCheckExtra]

# | Result | Name | Description
--- | --- | --- | ---
1 | success | The ForceAuthn attribute must be present because of minimum/SpidL1 : OK |
2 | success | The ForceAuthn attribute must be True because of minimum/SpidL1 : OK |
3 | success | SpidSpAuthnReqCheckExtra.test_AuthnRequest_extra : OK |